@@ -1,5 +1,5 @@
 from typing import Any, List, Dict, NamedTuple, Optional
-from aleph_alpha_client.prompt import Prompt, _to_serializable_prompt
+from aleph_alpha_client.prompt import Prompt
 
 
 class ExplanationRequest(NamedTuple):
@@ -13,7 +13,7 @@ class ExplanationRequest(NamedTuple):
 
     def to_json(self) -> Dict[str, Any]:
         payload = self._asdict()
-        payload["prompt"] = _to_serializable_prompt(self.prompt.items)
+        payload["prompt"] = self.prompt.to_json()
         return payload
 
 
