@@ -39,8 +39,6 @@ class Tokens(NamedTuple):
             The tokens you want to be passed to the model as part of your prompt.
 
         controls (List(TokenControl), optional, default None):
-            DISCLAIMER: This may not be supported at the time of package release.
-
             Used for Attention Manipulation. Provides the ability to change
             attention for given token ids.
 
@@ -162,7 +160,7 @@ class Prompt(NamedTuple):
 
 def _to_json(item: PromptItem) -> Mapping[str, Any]:
     if hasattr(item, "to_json"):
-        return item.to_json()
+        return item.to_json()  # type: ignore
     # Required for backwards compatibility
     # item could be a plain piece of text or a plain list of token-ids
     elif isinstance(item, str):
